#
# spec file for package perl-CGI-Simple
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-CGI-Simple
Version:        1.15
Release:        lp150.1.1
%define cpan_name CGI-Simple
Summary:        Simple totally OO CGI interface that is CGI.pm compliant
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/CGI-Simple/
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MANWAR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(Test::NoWarnings)
Requires:       perl(IO::Scalar)
Requires:       perl(Test::Exception)
Requires:       perl(Test::NoWarnings)
%{perl_requires}

%description
CGI::Simple provides a relatively lightweight drop in replacement for
CGI.pm. It shares an identical OO interface to CGI.pm for parameter
parsing, file upload, cookie handling and header generation. This module is
entirely object oriented, however a complete functional interface is
available by using the CGI::Simple::Standard module.

Essentially everything in CGI.pm that relates to the CGI (not HTML) side of
things is available. There are even a few new methods and additions to old
ones! If you are interested in what has gone on under the hood see the
Compatibility with CGI.pm section at the end.

In practical testing this module loads and runs about twice as fast as
CGI.pm depending on the precise task.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
%{__perl} Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Mon Mar  5 2018 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-CGI-Simple/Changes
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.115
  see /usr/share/doc/packages/perl-CGI-Simple/Changes
  1.114
  - Drop support for Perls older than 5.6.1.
  1.115 2014.10.19
  - Replace indirect calling of constructor both in code an documentation
    with direct calling.
    Write  CGI::Simle->new   instead of    new CGI::Simple
  - add tests to make sure the order of value is kept as they were passed in the QUERY_STRING
  - new co-maintainer (SZABGAB(
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Sat Jun  4 2011 lars@linux-schulserver.de
- require apache2-mod_perl instead of perl(HTTP::Request::Common)
  as perl-HTTP-Message provides the same on SLE_11
* Fri Feb  4 2011 chris@computersalat.de
- recreated by cpanspec 1.78.03
  o fix deps
- remove Author
* Thu Jan 27 2011 lars@linux-schulserver.de
- disable perl_requires macro for older Distributions
* Mon Jan 17 2011 lars@linux-schulserver.de
- update to 1.113:
  + fixes the following security bugs reported via CVE:
    CVE-2010-2761 - mime boundary issue
    CVE-2010-4410 - crlf injection
    CVE-2010-4411 - incomplete fix for crlf injection -
    and also via bnc #657343 and bnc #663396
  + Port max-age support from CGI.pm, to improve compatibility and
  RFC-compliance
  + some fixes in the testsuite
  + Sync cookie references with CGI.pm: add reference to the
  newer RFC 2695
  + documentation fixes
  + Optimize Vars(): Don't build %%hash if we aren't going to use it,
  and don't call "tie" unless we need to
  + Added "+" and "\." to the mime character class.
  + Fixed wrong match for mimetypes.
- remove perl-CGI-Simple-CVE-2010-2761.patch (included upstream)
* Wed Dec  8 2010 lrupp@suse.de
- fix CVE-2010-2761 (bnc#657731) - multipart mime boundary
  (perl-CGI-Simple-CVE-2010-2761.patch)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Sep  2 2009 chris@computersalat.de
- update to 1.112
  * 1.112   2009-05-31
  - (thanks bingos) added missing IO::Scalar dependency.
  * 1.111   2009-05-28
  - Implemented Michael Nachbaur fixes for multipart form data
    handling.
  * 1.110   2009-05-24
  - Added missing test to manifest / distro.
  - Added a test to ensure the manifest is consistent.
  - Migrated to git.
  * 1.109   2009-04-16
  - Added support for HttpOnly to CGI::Simple::Cookie. Thanks to
    Scott Thomson for the patch.
  * 1.108   2009-03-13
  - Remove bogus references to Selfloader in documenation. No
    functional changes.
  * 1.107   2009-03-07
  - CGI::Simple::Cookie, fixed bug when cookie had both leading and
    trailing white space (RT#34314, Ron Savage and Mark Stosberg)
  - Accept a comma as well as semi-colon as a cookie separator. This
    is consistent with CGI.pm as well as RFC 2965, which states: "A
    server SHOULD also accept comma (,) as the separator between cookie-
    values for future compatibility." (Mark Stosberg)
  - Support cookies which have an equals sign in the value. Ported
    from CGI.pm (Mark Stosberg)
  - Support cookies in which one of multiple values is empty. Ported
    from CGI.pm (Mark Stosberg)
  - Fixed bug when calling unescapeHTML on HTML that wasn't
    properly escaped in the first place. Thanks to M-Uchino and
    Mark Stosberg.
  - Removed bogus dependency on version.pm.
  - Add heuristic to upload to handle the case where no boundary is
    specified in CONTENT_TYPE. See #14838.
- added perl-macros
- specmods
  o added header
  o fixed deps
  o added Url
  o removed Provides perl-CGI-Carp
* Sun Nov 30 2008 lars@linux-schulserver.de
- initial version 1.106
